@@ -2,12 +2,18 @@
 
 from jsondaora.dataclasses import asdataclass
 from jsondaora.decorator import jsondaora
-from jsondaora.schema import IntegerField, StringField, integer, string
+from jsondaora.schema import (
+    IntegerField,
+    StringField,
+    integer,
+    jsonschema_asdataclass,
+    string,
+)
 from jsondaora.serializers import dataclass_asjson, typed_dict_asjson
 from jsondaora.typed_dict import as_typed_dict, as_typed_dict_field
 
 
-__version__ = '0.11.1'
+__version__ = '0.12.0'
 
 
 __all__ = [
@@ -21,4 +27,5 @@ __all__ = [
     'typed_dict_asjson',
     'integer',
     'string',
+    'jsonschema_asdataclass',
 ]
